@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.66';
+$Test::BDD::Cucumber::Executor::VERSION = '0.660001';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.66
+version 0.660001
 
 =head1 DESCRIPTION
 
@@ -36,6 +36,7 @@ require Test2::Formatter::TAP;
 # Needed for subtest() -- we don't want to import all its functions though
 require Test::More;
 
+use Test::BDD::Cucumber::StepFile ();
 use Test::BDD::Cucumber::StepContext;
 use Test::BDD::Cucumber::Util;
 use Test::BDD::Cucumber::Model::Result;
@@ -603,16 +604,6 @@ sub dispatch {
             my $ctx = context();
             $ctx->pass( "Starting to execute step: " . $context->text );
 
-            # Execute!
-            no warnings 'redefine';
-
-            local *Test::BDD::Cucumber::StepFile::S = sub {
-                return $context->stash->{'scenario'};
-            };
-            local *Test::BDD::Cucumber::StepFile::C = sub {
-                return $context;
-            };
-
             # Take a copy of this. Turns out actually matching against it
             # directly causes all sorts of weird-ass heisenbugs which mst has
             # promised to investigate.
@@ -627,7 +618,18 @@ sub dispatch {
             @match_locations = pairwise { [ $a, $b ] } @starts, @ends;
 
             # OK, actually execute
-            eval { $coderef->($context) };
+            eval {
+                no warnings 'redefine';
+
+                local *Test::BDD::Cucumber::StepFile::_S = sub {
+                    return $context->stash->{'scenario'};
+                };
+                local *Test::BDD::Cucumber::StepFile::_C = sub {
+                    return $context;
+                };
+
+                $coderef->($context)
+            };
             if ($@) {
                 $ctx->fail("Step ran successfully", $@);
             }
